@@ -85,7 +85,7 @@ class BaseEnvironment(object):
                 params.extend(["--config", fh.name])
             if constraints:
                 params.extend(['--constraints', constraints])
-            if num_units != 1:
+            if num_units not in (1, None):
                 params.extend(["--num-units", str(num_units)])
             if charm_url.startswith('local'):
                 if repo == "":
